embassy-mcxa

Crates

git

Versions

mcx-a256

Flavors

Crc

Struct Crc 

pub struct Crc<'d, M> { /* private fields */ }
CRC driver.

Implementations

Source

impl<'d> Crc<'d, Crc16>

pub fn new_crc16<T: Instance>(peri: Peri<'d, T>, config: Config) -> Self

Instantiates a new CRC peripheral driver in 16-bit mode

pub fn new_algorithm16<T: Instance>( peri: Peri<'d, T>, algorithm: Algorithm16, ) -> Self

Instantiates a new CRC peripheral driver for the given Algorithm16.

pub fn new_a<T: Instance>(peri: Peri<'d, T>) -> Self

Instantiates a new CRC peripheral for the A algorithm.

pub fn new_aug_ccitt<T: Instance>(peri: Peri<'d, T>) -> Self

Instantiates a new CRC peripheral for the AugCcitt algorithm.

pub fn new_arc<T: Instance>(peri: Peri<'d, T>) -> Self

Instantiates a new CRC peripheral for the Arc algorithm.

pub fn new_buypass<T: Instance>(peri: Peri<'d, T>) -> Self

Instantiates a new CRC peripheral for the Buypass algorithm.

pub fn new_ccitt_false<T: Instance>(peri: Peri<'d, T>) -> Self

Instantiates a new CRC peripheral for the CcittFalse algorithm.

pub fn new_ccitt_zero<T: Instance>(peri: Peri<'d, T>) -> Self

Instantiates a new CRC peripheral for the CcittZero algorithm.

pub fn new_cdma_2000<T: Instance>(peri: Peri<'d, T>) -> Self

Instantiates a new CRC peripheral for the Cdma2000 algorithm.

pub fn new_dds_110<T: Instance>(peri: Peri<'d, T>) -> Self

Instantiates a new CRC peripheral for the Dds110 algorithm.

pub fn new_dect_x<T: Instance>(peri: Peri<'d, T>) -> Self

Instantiates a new CRC peripheral for the DectX algorithm.

pub fn new_dnp<T: Instance>(peri: Peri<'d, T>) -> Self

Instantiates a new CRC peripheral for the Dnp algorithm.

pub fn new_en13757<T: Instance>(peri: Peri<'d, T>) -> Self

Instantiates a new CRC peripheral for the En13757 algorithm.

pub fn new_genibus<T: Instance>(peri: Peri<'d, T>) -> Self

Instantiates a new CRC peripheral for the Genibus algorithm.

pub fn new_kermit<T: Instance>(peri: Peri<'d, T>) -> Self

Instantiates a new CRC peripheral for the Kermit algorithm.

pub fn new_maxim<T: Instance>(peri: Peri<'d, T>) -> Self

Instantiates a new CRC peripheral for the Maxim algorithm.

pub fn new_mcrf4xx<T: Instance>(peri: Peri<'d, T>) -> Self

Instantiates a new CRC peripheral for the Mcrf4xx algorithm.

pub fn new_modbus<T: Instance>(peri: Peri<'d, T>) -> Self

Instantiates a new CRC peripheral for the Modbus algorithm.

pub fn new_riello<T: Instance>(peri: Peri<'d, T>) -> Self

Instantiates a new CRC peripheral for the Riello algorithm.

pub fn new_t10_dif<T: Instance>(peri: Peri<'d, T>) -> Self

Instantiates a new CRC peripheral for the T10Dif algorithm.

pub fn new_teledisk<T: Instance>(peri: Peri<'d, T>) -> Self

Instantiates a new CRC peripheral for the Teledisk algorithm.

pub fn new_tms_37157<T: Instance>(peri: Peri<'d, T>) -> Self

Instantiates a new CRC peripheral for the Tms37157 algorithm.

pub fn new_usb<T: Instance>(peri: Peri<'d, T>) -> Self

Instantiates a new CRC peripheral for the Usb algorithm.

pub fn new_x25<T: Instance>(peri: Peri<'d, T>) -> Self

Instantiates a new CRC peripheral for the X25 algorithm.

pub fn new_xmodem<T: Instance>(peri: Peri<'d, T>) -> Self

Instantiates a new CRC peripheral for the Xmodem algorithm.

pub fn feed<W: Word>(&mut self, data: &[W])

Feeds a slice of Words into the CRC peripheral.

The input is strided efficiently into as many u32s as possible, falling back to smaller writes for the remainder.

pub fn finalize(self) -> u16

Finalizes the CRC calculation and reads the resulting CRC from the hardware consuming self.

Source

impl<'d> Crc<'d, Crc32>

pub fn new_crc32<T: Instance>(peri: Peri<'d, T>, config: Config) -> Self

Instantiates a new CRC peripheral driver in 32-bit mode

pub fn new_algorithm32<T: Instance>( peri: Peri<'d, T>, algorithm: Algorithm32, ) -> Self

Instantiates a new CRC peripheral driver for the given Algorithm32.

pub fn new_bzip2<T: Instance>(peri: Peri<'d, T>) -> Self

Instantiates a new CRC peripheral for the Bzip2 algorithm.

pub fn new_c<T: Instance>(peri: Peri<'d, T>) -> Self

Instantiates a new CRC peripheral for the C algorithm.

pub fn new_d<T: Instance>(peri: Peri<'d, T>) -> Self

Instantiates a new CRC peripheral for the D algorithm.

pub fn new_iso_hdlc<T: Instance>(peri: Peri<'d, T>) -> Self

Instantiates a new CRC peripheral for the IsoHdlc algorithm.

pub fn new_jam_crc<T: Instance>(peri: Peri<'d, T>) -> Self

Instantiates a new CRC peripheral for the JamCrc algorithm.

pub fn new_mpeg2<T: Instance>(peri: Peri<'d, T>) -> Self

Instantiates a new CRC peripheral for the Mpeg2 algorithm.

pub fn new_posix<T: Instance>(peri: Peri<'d, T>) -> Self

Instantiates a new CRC peripheral for the Posix algorithm.

pub fn new_q<T: Instance>(peri: Peri<'d, T>) -> Self

Instantiates a new CRC peripheral for the Q algorithm.

pub fn new_xfer<T: Instance>(peri: Peri<'d, T>) -> Self

Instantiates a new CRC peripheral for the Xfer algorithm.

pub fn feed<W: Word>(&mut self, data: &[W])

Feeds a slice of Words into the CRC peripheral.

The input is strided efficiently into as many u32s as possible, falling back to smaller writes for the remainder.

pub fn finalize(self) -> u32

Finalizes the CRC calculation and reads the resulting CRC from the hardware consuming self.